==> Abjad-2.20.tar.gz: Abjad-2.20/abjad/tools/topleveltools/show.py <==
# -*- coding: utf-8 -*-


def show(argument, return_timing=False, **keywords):
    r'''Shows `argument`.

    ..  container:: example

        Shows note:

        ::

            >>> note = Note("c'4")
            >>> show(note) # doctest: +SKIP

        ..  doctest::

            >>> f(note)
            c'4

    ..  container:: example

        Shows staff:

        ::

            >>> staff = Staff("c'4 d' e' f'")
            >>> show(staff) # doctest: +SKIP

        ..  doctest::

            >>> f(staff)
            \new Staff {
                c'4
                d'4
                e'4
                f'4
            }

    Makes LilyPond input files and output PDF.

    Writes LilyPond input file and output PDF to Abjad output directory.

    Opens output PDF.
    
    Returns none when `return_timing` is false.

    Returns pair of `abjad_formatting_time` and `lilypond_rendering_time`
    when `return_timing` is true.
    '''
    import abjad
    if not hasattr(argument, '__illustrate__'):
        message = 'must have __illustrate__ method: {!r}.'
        message = message.format(argument)
        raise Exception(message)
    result = abjad.persist(argument).as_pdf(**keywords)
    pdf_file_path = result[0]
    abjad_formatting_time = result[1]
    lilypond_rendering_time = result[2]
    success = result[3]
    if success:
        abjad.systemtools.IOManager.open_file(pdf_file_path)
    else:
        with open(abjad.abjad_configuration.lilypond_log_file_path, 'r') as fp:
            print(fp.read())
    if return_timing:
        return abjad_formatting_time, lilypond_rendering_time

==> Abjad-2.21.tar.gz: Abjad-2.21/abjad/tools/topleveltools/show.py <==
# -*- coding: utf-8 -*-


def show(argument, return_timing=False, **keywords):
    r'''Shows `argument`.

    ::

        >>> import abjad

    ..  container:: example

        Shows note:

        ::

            >>> note = abjad.Note("c'4")
            >>> show(note) # doctest: +SKIP

        ..  docs::

            >>> f(note)
            c'4

    ..  container:: example

        Shows staff:

        ::

            >>> staff = abjad.Staff("c'4 d' e' f'")
            >>> show(staff) # doctest: +SKIP

        ..  docs::

            >>> f(staff)
            \new Staff {
                c'4
                d'4
                e'4
                f'4
            }

    Makes LilyPond input files and output PDF.

    Writes LilyPond input file and output PDF to Abjad output directory.

    Opens output PDF.
    
    Returns none when `return_timing` is false.

    Returns pair of `abjad_formatting_time` and `lilypond_rendering_time`
    when `return_timing` is true.
    '''
    import abjad
    if not hasattr(argument, '__illustrate__'):
        message = 'must have __illustrate__ method: {!r}.'
        message = message.format(argument)
        raise Exception(message)
    result = abjad.persist(argument).as_pdf(**keywords)
    pdf_file_path = result[0]
    abjad_formatting_time = result[1]
    lilypond_rendering_time = result[2]
    success = result[3]
    if success:
        abjad.IOManager.open_file(pdf_file_path)
    else:
        with open(abjad.abjad_configuration.lilypond_log_file_path, 'r') as fp:
            print(fp.read())
    if return_timing:
        return abjad_formatting_time, lilypond_rendering_time
